@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -59,10 +59,10 @@
 
 /* -- version --------------------------------------------------------------- */
 constexpr auto G_APP_NAME      = "Giada";
-constexpr auto G_VERSION_STR   = "0.20.0";
+constexpr auto G_VERSION_STR   = "0.20.1";
 constexpr int  G_VERSION_MAJOR = 0;
 constexpr int  G_VERSION_MINOR = 20;
-constexpr int  G_VERSION_PATCH = 0;
+constexpr int  G_VERSION_PATCH = 1;
 
 constexpr auto CONF_FILENAME = "giada.conf";
 
@@ -82,8 +82,8 @@ live input latency, keep it small! */
 constexpr int G_EVENT_DISPATCHER_RATE_MS = 5;
 
 /* -- GUI ------------------------------------------------------------------- */
-constexpr float G_GUI_REFRESH_RATE   = 1 / 30.0f; // 30 fps
-constexpr float G_GUI_PLUGIN_RATE    = 1 / 30.0f; // 30 fps
+constexpr int   G_GUI_FPS            = 30;
+constexpr float G_GUI_REFRESH_RATE   = 1 / static_cast<float>(G_GUI_FPS);
 constexpr int   G_GUI_FONT_SIZE_BASE = 12;
 constexpr int   G_GUI_INNER_MARGIN   = 4;
 constexpr int   G_GUI_OUTER_MARGIN   = 8;
@@ -193,20 +193,21 @@ constexpr int LOG_MODE_FILE   = 2;
 
 /* -- unique IDs of mainWin's subwindows ------------------------------------ */
 /* -- wid > 0 are reserved by gg_keyboard ----------------------------------- */
-constexpr int WID_BEATS         = -1;
-constexpr int WID_BPM           = -2;
-constexpr int WID_ABOUT         = -3;
-constexpr int WID_FILE_BROWSER  = -4;
-constexpr int WID_CONFIG        = -5;
-constexpr int WID_FX_LIST       = -6;
-constexpr int WID_ACTION_EDITOR = -7;
-constexpr int WID_SAMPLE_EDITOR = -8;
-constexpr int WID_FX            = -9;
-constexpr int WID_KEY_GRABBER   = -10;
-constexpr int WID_SAMPLE_NAME   = -11;
-constexpr int WID_FX_CHOOSER    = -12;
-constexpr int WID_MIDI_INPUT    = -13;
-constexpr int WID_MIDI_OUTPUT   = -14;
+constexpr int WID_BEATS          = -1;
+constexpr int WID_BPM            = -2;
+constexpr int WID_ABOUT          = -3;
+constexpr int WID_FILE_BROWSER   = -4;
+constexpr int WID_CONFIG         = -5;
+constexpr int WID_FX_LIST        = -6;
+constexpr int WID_ACTION_EDITOR  = -7;
+constexpr int WID_SAMPLE_EDITOR  = -8;
+constexpr int WID_FX             = -9;
+constexpr int WID_KEY_GRABBER    = -10;
+constexpr int WID_SAMPLE_NAME    = -11;
+constexpr int WID_FX_CHOOSER     = -12;
+constexpr int WID_MIDI_INPUT     = -13;
+constexpr int WID_MIDI_OUTPUT    = -14;
+constexpr int WID_MISSING_ASSETS = -15;
 
 /* -- patch signals --------------------------------------------------------- */
 constexpr int G_PATCH_UNSUPPORTED = -2;
