@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,34 +26,33 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_OUTPUT_MIDI_CH_H
 #define GD_MIDI_OUTPUT_MIDI_CH_H
 
-
 #include "midiOutputBase.h"
 
-
-namespace giada {
-namespace v 
+namespace giada
 {
+namespace v
+{
+class geChoice;
 class gdMidiOutputMidiCh : public gdMidiOutputBase
 {
 public:
-
 	gdMidiOutputMidiCh(ID channelId);
 
-private:
+	void rebuild() override;
 
-	static void cb_enableOut (Fl_Widget* w, void* p);
-	static void cb_setChannel(Fl_Widget* w, void* p);
-	void cb_enableOut();
-	void cb_setChannel();
+  private:
+	static void cb_enableOut(Fl_Widget* /*w*/, void* p);
+	static void cb_setChannel(Fl_Widget* /*w*/, void* p);
+	void        cb_enableOut();
+	void        cb_setChannel();
 
 	geCheck*  m_enableOut;
 	geChoice* m_chanListOut;
 };
-}} // giada::v::
-
+} // namespace v
+} // namespace giada
 
 #endif
