@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,8 +29,6 @@
 
 #include "gui/elems/basics/pack.h"
 
-class geButton;
-
 namespace giada::v
 {
 class geMainMenu : public gePack
@@ -39,15 +37,8 @@ public:
 	geMainMenu(int x, int y);
 
 private:
-	static void cb_file(Fl_Widget* /*w*/, void* p);
-	static void cb_edit(Fl_Widget* /*w*/, void* p);
-	void        cb_file();
-	void        cb_edit();
-
-	geButton* file;
-	geButton* edit;
-	geButton* config;
-	geButton* about;
+	void cb_file();
+	void cb_edit();
 };
 } // namespace giada::v
 
