@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,26 +24,24 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/Fl.H>
-#include "core/channels/sampleChannel.h"
+#include "boostTool.h"
 #include "core/const.h"
-#include "core/waveFx.h"  
+#include "core/waveFx.h"
 #include "glue/channel.h"
-#include "utils/gui.h"
-#include "utils/string.h"
-#include "utils/math.h"
 #include "gui/dialogs/sampleEditor.h"
-#include "gui/elems/basics/dial.h"
-#include "gui/elems/basics/input.h"
 #include "gui/elems/basics/box.h"
 #include "gui/elems/basics/button.h"
+#include "gui/elems/basics/dial.h"
+#include "gui/elems/basics/input.h"
+#include "utils/gui.h"
+#include "utils/math.h"
+#include "utils/string.h"
 #include "waveTools.h"
-#include "boostTool.h"
+#include <FL/Fl.H>
 
-
-namespace giada {
-namespace v 
+namespace giada
+{
+namespace v
 {
 geBoostTool::geBoostTool(int X, int Y)
 : Fl_Pack(X, Y, 220, G_GUI_UNIT)
@@ -52,10 +50,10 @@ geBoostTool::geBoostTool(int X, int Y)
 	spacing(G_GUI_INNER_MARGIN);
 
 	begin();
-		label     = new geBox   (0, 0, u::gui::getStringWidth("Boost"), G_GUI_UNIT, "Boost", FL_ALIGN_RIGHT);
-		dial      = new geDial  (0, 0, G_GUI_UNIT, G_GUI_UNIT);
-		input     = new geInput (0, 0, 70, G_GUI_UNIT);
-		normalize = new geButton(0, 0, 70, G_GUI_UNIT, "Normalize");
+	label     = new geBox(0, 0, u::gui::getStringRect("Boost").w, G_GUI_UNIT, "Boost", FL_ALIGN_RIGHT);
+	dial      = new geDial(0, 0, G_GUI_UNIT, G_GUI_UNIT);
+	input     = new geInput(0, 0, 70, G_GUI_UNIT);
+	normalize = new geButton(0, 0, 70, G_GUI_UNIT, "Normalize");
 	end();
 
 	dial->range(1.0f, 10.0f);
@@ -67,10 +65,8 @@ geBoostTool::geBoostTool(int X, int Y)
 	normalize->callback(cb_normalize, (void*)this);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBoostTool::rebuild()
 {
 	/*
@@ -81,18 +77,14 @@ void geBoostTool::rebuild()
 	dial->value(ch->getBoost() <= 10.0f ? ch->getBoost() : 10.0f);*/
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geBoostTool::cb_setBoost   (Fl_Widget* w, void* p) { ((geBoostTool*)p)->cb_setBoost(); }
-void geBoostTool::cb_setBoostNum(Fl_Widget* w, void* p) { ((geBoostTool*)p)->cb_setBoostNum(); }
-void geBoostTool::cb_normalize  (Fl_Widget* w, void* p) { ((geBoostTool*)p)->cb_normalize(); }
-
+void geBoostTool::cb_setBoost(Fl_Widget* /*w*/, void* p) { ((geBoostTool*)p)->cb_setBoost(); }
+void geBoostTool::cb_setBoostNum(Fl_Widget* /*w*/, void* p) { ((geBoostTool*)p)->cb_setBoostNum(); }
+void geBoostTool::cb_normalize(Fl_Widget* /*w*/, void* p) { ((geBoostTool*)p)->cb_normalize(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void geBoostTool::cb_setBoost()
 {
 	/*const m::SampleChannel* ch = static_cast<gdSampleEditor*>(window())->ch;
@@ -100,10 +92,8 @@ void geBoostTool::cb_setBoost()
 	c::channel::setBoost(ch->id, dial->value());*/
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBoostTool::cb_setBoostNum()
 {
 	/*const m::SampleChannel* ch = static_cast<gdSampleEditor*>(window())->ch;
@@ -111,12 +101,11 @@ void geBoostTool::cb_setBoostNum()
 	c::channel::setBoost(ch->id, u::math::dBtoLinear(atof(input->value())));*/
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBoostTool::cb_normalize()
 {
 }
 
-}} // giada::v::
+} // namespace v
+} // namespace giada
