@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,27 +24,16 @@
  *
  * -------------------------------------------------------------------------- */
 
+#include "core/engine.h"
+#include "gui/ui.h"
 
-#include <atomic>
-#include <FL/Fl.H>
-#include "core/init.h"
-
-
-class gdMainWindow* G_MainWin = nullptr;
-
+giada::m::Engine g_engine;
+giada::v::Ui     g_ui(g_engine.recorder);
 
 int main(int argc, char** argv)
 {
-	using namespace giada;
-
-	m::init::startup(argc, argv);
-
-	int ret = Fl::run();
-
-	m::init::shutdown();
-
-	return ret;
-}
-
-
-
+	if (int ret = giada::m::init::tests(argc, argv); ret != -1)
+		return ret;
+	giada::m::init::startup(argc, argv);
+	return giada::m::init::run();
+}
\ No newline at end of file
